@@ -14,10 +14,8 @@
  * SOFTWARE.
  */
 
-use {
-  super::{accept, empty_scope},
-  crate::lalr::TokenType::StartTextualExpression,
-};
+use super::{accept, empty_scope};
+use crate::lalr::TokenType::StartTextualExpression;
 
 #[test]
 fn abs() {
